==> haskell-cmdargs-0.10.13-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-cmdargs/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cmdargs
version: 0.10.13
id: cmdargs-0.10.13-bef2ab6ecde2bd42e13eb0f01d9aba51
key: cmdar_GjqmBnMST2K5Mjh1gX3IM5
license: BSD3
copyright: Neil Mitchell 2009-2015
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: http://community.haskell.org/~ndm/cmdargs/
synopsis: Command line argument processing
description:
    This library provides an easy way to define command line parsers. Most users
    will want to use the "System.Console.CmdArgs.Implicit" module, whose
    documentation contains an example.
    .
    * "System.Console.CmdArgs.Explicit" provides a way to write command line
    parsers for both single mode programs (most programs) and multiple
    mode programs (e.g. darcs or cabal). Parsers are defined by constructing
    a data structure.
    .
    * "System.Console.CmdArgs.Implicit" provides a way to concisely define
    command line parsers, up to three times shorter than getopt. These parsers
    are translated into the Explicit data type.
    .
    * "System.Console.CmdArgs.GetOpt" provides a wrapper allowing compatiblity
    with existing getopt parsers, mapping to the Explicit data type.
    .
    For a general reference on what command line flags are commonly used,
    see <http://www.faqs.org/docs/artu/ch10s05.html>.
category: Console
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
exposed-modules:
    System.Console.CmdArgs System.Console.CmdArgs.Annotate
    System.Console.CmdArgs.Default System.Console.CmdArgs.Explicit
    System.Console.CmdArgs.GetOpt System.Console.CmdArgs.Implicit
    System.Console.CmdArgs.Text System.Console.CmdArgs.Helper
    System.Console.CmdArgs.Verbosity System.Console.CmdArgs.Quote
hidden-modules: Data.Generics.Any Data.Generics.Any.Prelude
                System.Console.CmdArgs.Explicit.Complete
                System.Console.CmdArgs.Explicit.ExpandArgsAt
                System.Console.CmdArgs.Explicit.Help
                System.Console.CmdArgs.Explicit.Process
                System.Console.CmdArgs.Explicit.SplitJoin
                System.Console.CmdArgs.Explicit.Type
                System.Console.CmdArgs.Implicit.Ann
                System.Console.CmdArgs.Implicit.Global
                System.Console.CmdArgs.Implicit.Local
                System.Console.CmdArgs.Implicit.Reader
                System.Console.CmdArgs.Implicit.Reform
                System.Console.CmdArgs.Implicit.Type
                System.Console.CmdArgs.Implicit.UI
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/cmdargs-0.10.13
library-dirs: /usr/lib/ghc-7.10.3/site-local/cmdargs-0.10.13
data-dir: /usr/share/arm-linux-ghc-7.10.3/cmdargs-0.10.13
hs-libraries: HScmdargs-0.10.13-GjqmBnMST2K5Mjh1gX3IM5
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-cmdargs/html/cmdargs.haddock
haddock-html: /usr/share/doc/haskell-cmdargs/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cmdargs-0.10.14-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-cmdargs/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cmdargs
version: 0.10.14
id: cmdargs-0.10.14-ea4d1877c8c5fa6ed8eebd52f962ac3b
key: cmdar_3X5ZqkX9cRxBIIPeikYpqr
license: BSD3
copyright: Neil Mitchell 2009-2016
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/cmdargs#readme
synopsis: Command line argument processing
description:
    This library provides an easy way to define command line parsers. Most users
    will want to use the "System.Console.CmdArgs.Implicit" module, whose
    documentation contains an example.
    .
    * "System.Console.CmdArgs.Explicit" provides a way to write command line
    parsers for both single mode programs (most programs) and multiple
    mode programs (e.g. darcs or cabal). Parsers are defined by constructing
    a data structure.
    .
    * "System.Console.CmdArgs.Implicit" provides a way to concisely define
    command line parsers, up to three times shorter than getopt. These parsers
    are translated into the Explicit data type.
    .
    * "System.Console.CmdArgs.GetOpt" provides a wrapper allowing compatiblity
    with existing getopt parsers, mapping to the Explicit data type.
    .
    For a general reference on what command line flags are commonly used,
    see <http://www.faqs.org/docs/artu/ch10s05.html>.
category: Console
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
exposed-modules:
    System.Console.CmdArgs System.Console.CmdArgs.Annotate
    System.Console.CmdArgs.Default System.Console.CmdArgs.Explicit
    System.Console.CmdArgs.GetOpt System.Console.CmdArgs.Implicit
    System.Console.CmdArgs.Text System.Console.CmdArgs.Helper
    System.Console.CmdArgs.Verbosity System.Console.CmdArgs.Quote
hidden-modules: Data.Generics.Any Data.Generics.Any.Prelude
                System.Console.CmdArgs.Explicit.Complete
                System.Console.CmdArgs.Explicit.ExpandArgsAt
                System.Console.CmdArgs.Explicit.Help
                System.Console.CmdArgs.Explicit.Process
                System.Console.CmdArgs.Explicit.SplitJoin
                System.Console.CmdArgs.Explicit.Type
                System.Console.CmdArgs.Implicit.Ann
                System.Console.CmdArgs.Implicit.Global
                System.Console.CmdArgs.Implicit.Local
                System.Console.CmdArgs.Implicit.Reader
                System.Console.CmdArgs.Implicit.Reform
                System.Console.CmdArgs.Implicit.Type
                System.Console.CmdArgs.Implicit.UI
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/cmdargs-0.10.14
library-dirs: /usr/lib/ghc-7.10.3/site-local/cmdargs-0.10.14
data-dir: /usr/share/arm-linux-ghc-7.10.3/cmdargs-0.10.14
hs-libraries: HScmdargs-0.10.14-3X5ZqkX9cRxBIIPeikYpqr
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-cmdargs/html/cmdargs.haddock
haddock-html: /usr/share/doc/haskell-cmdargs/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
